@@ -87,7 +87,7 @@ class ZeroShotClassifierAnnotator(AnnotatorBase):
         params: ZeroShotClassifierParameters = cast(
             ZeroShotClassifierParameters, parameters
         )
-        if params.hypothesis_template is None:
+        if params.hypothesis_template is None or not params.hypothesis_template.strip():
             if params.model == TrfModel.distilbert_base_uncased_mnli:
                 params.hypothesis_template = "This example is {}."
             elif params.model == TrfModel.camembert_base_xnli:
